/**

 *  PROCESSING CODE 
 *  uses a handshake system to start communcating with arduino

 *  receives an array of data in teh packet form
 
 *  START_BYTE sensorData DELIMITER sensorData DELIMITER sensorData DELIMITER END_BYTE
 
 */

// import the needed libraries

import processing.serial.*;


char START_BYTE  =  42 ;   //  42 = * 
char DELIMITER   =  44 ;   //  44 = ,  
char END_BYTE    =  35 ;   //  35 = # 
char WHITE_SPACE =  32 ;   //  32 = ' ' 

String TOKENS = new String( ""  + WHITE_SPACE + START_BYTE + DELIMITER + END_BYTE);  // MAKE A STRING OF TOKENS

// setup the local USB variables
Serial usbPort;
boolean madeUSBcontact = false;

// array to hold incomming data

int[] sensorData;

void setup() 
{
  size( 600, 255 );
  background( 67 );
  noStroke( );

  // setup the USB connection to receive local data 
  // uncomment this line to see attached serial devices
  
  //println( Serial.list() );
  usbPort = new Serial( this,  Serial.list()[2],  9600 ); // use usb serial, 9600 baud
  usbPort.bufferUntil( END_BYTE ); // lf == line feed, ASCII 10; the line ending from arduino
  
}


void draw() {
  
  if ( ! madeUSBcontact ){     // if you have not heard from Arduino ... 
      usbPort.write( '\r' );   // send a carriage return to start communication 
  } else {
  
  // put YOUR other code here
  
  visualizeData();
  
  }
  
}


// this function is called when a serial event (data from Arduino) occurs

void serialEvent( Serial usbPort ){
  
      madeUSBcontact = true ;   // set contact flag
  
      String usbString = usbPort.readStringUntil( END_BYTE );  // read string from Arduino
      // println("usbString " +  usbString);                   // for debug -- or if you want to see the string
      
      if ( usbString != null ){
          
           usbString = trim( usbString );         // remove white spaces  
            
           // parse the string into ints
           int incomingSensorStream[] = int (splitTokens( usbString,  TOKENS ));  // **  note this casts the incoming data as INT 
           
           // this is a hack to get the data from incomingSensorStream (local) into sensorData (global)
           
           sensorData = new int[incomingSensorStream.length];
           arrayCopy( incomingSensorStream  , sensorData ); 
                  
              // println("sensorData " + i + "\t" + sensorData[i]);  // debug to see message locally turn off once client running
        }  // end if
      
    
      
      usbPort.clear();        // dumps buffer before asking for next data point
      usbPort.write( '\r' );  // send a carriage return to continue communication 
          
}

  void visualizeData (){
    
    for (int i = 0 ; i < sensorData.length; i ++){
      
      // if you are using digital sensors uncomment this line
      fill (sensorData[i]*255);
      
      // if you are using analog sensors uncomment this line
      //fill (sensorData[i]);
      
      rect(i*25+50, width/2, 50, 50);
      
    } // end for loop
      
      
    
  } // end visualize data


